@@ -8,27 +8,28 @@ from . import urls, __title__
 
 class StructuresMenuItem(MenuItemHook):
     """ This class ensures only authorized users will see the menu entry """
+
     def __init__(self):
         # setup menu entry for sidebar
         MenuItemHook.__init__(
             self,
             _(__title__),
-            'fa fa-building fa-fw',
-            'structures:index',
-            navactive=['structures:index']
+            "fa fa-building fa-fw",
+            "structures:index",
+            navactive=["structures:index"],
         )
 
     def render(self, request):
-        if request.user.has_perm('structures.basic_access'):
+        if request.user.has_perm("structures.basic_access"):
             return MenuItemHook.render(self, request)
-        return ''
+        return ""
 
 
-@hooks.register('menu_item_hook')
+@hooks.register("menu_item_hook")
 def register_menu():
     return StructuresMenuItem()
 
 
-@hooks.register('url_hook')
+@hooks.register("url_hook")
 def register_urls():
-    return UrlHook(urls, 'structures', r'^structures/')
+    return UrlHook(urls, "structures", r"^structures/")
